Prints a compact numeric summary of the key QM diagnostic metrics.
Usage
# S3 method for class 'precip_qm_diagnostics'
summary(object, ...)Prints a compact numeric summary of the key QM diagnostic metrics.
# S3 method for class 'precip_qm_diagnostics'
summary(object, ...)