Scans a vector of dates and returns the integer indices of all elements that
correspond to February 29. If the vector contains no leap days, returns NULL.
Scans a vector of dates and returns the integer indices of all elements that
correspond to February 29. If the vector contains no leap days, returns NULL.